@@ -6,16 +6,20 @@ from btb.tuning.hyperparams.boolean import BooleanHyperParam
 from btb.tuning.hyperparams.categorical import CategoricalHyperParam
 from btb.tuning.hyperparams.numerical import FloatHyperParam, IntHyperParam
 from btb.tuning.tunable import Tunable
-from btb.tuning.tuners.gaussian_process import GPEiTuner, GPTuner
+from btb.tuning.tuners.base import StopTuning
+from btb.tuning.tuners.gaussian_process import GCPEiTuner, GCPTuner, GPEiTuner, GPTuner
 from btb.tuning.tuners.uniform import UniformTuner
 
 __all__ = (
     'BooleanHyperParam',
     'CategoricalHyperParam',
+    'GCPEiTuner',
+    'GCPTuner',
     'GPEiTuner',
     'GPTuner',
     'FloatHyperParam',
     'IntHyperParam',
+    'StopTuning',
     'Tunable',
     'UniformTuner',
 )
